%==========================================================================
% Figure 8 / Numerical example
% see optimum.m for details
%==========================================================================

PARAM(1)=0.0001;   %pi;
PARAM(2)=0.01;     %p1;
PARAM(3)=0.25;     %ci;
PARAM(4)=20;       %cnc;
PARAM(5)=100;      %ca;
PARAM(6)=2;        %cs_nc;
PARAM(7)=2.5;      %cs_c;
PARAM(8)=0.01;     %alpha;
PARAM(9)=0.01;     %beta;
PARAM(10)=1e-6;    %deltamax;
PARAM(11)=0.03;    %phimax;


% Scenario 1
param=PARAM;
param(8)=0.0;     %alpha;
param(9)=0.0;     %beta;
[mo1,ro1,Co1,phio1,chainlog1]=optimum(param,[],[],[0 1 1],1);
NMAX=max(chainlog1(:,1));

% Scenario 2
param(8)=0.01;     %alpha;
param(9)=0.01;     %beta;
[mo2,ro2,Co2,phio2,chainlog2]=optimum(param,[],[1 1],[0 1 1],1);
NMAX=max(NMAX,max(chainlog2(:,1)));

% Scenario 3
param(8)=0.01;     %alpha;
param(9)=0.01;     %beta;
[mo3,ro3,Co3,phio3,chainlog3]=optimum(param,[],[],[0 1 1],1);
NMAX=max(NMAX,max(chainlog2(:,1)));


% Resetando o gerador de nmeros aleatrios
rand('state',3);

% Definindo a variao de custos permitida
erro=0.25;
nsim=10000;

MALEAT=unifrnd(1-erro,1+erro,nsim,5);
OUTPUT=zeros(nsim,3);
	
for i=1:nsim

    % Calculando cada um dos preos
    param(3)=PARAM(3)*MALEAT(i,1);     %ci;
    param(4)=PARAM(4)*MALEAT(i,2);     %cnc;
    param(5)=PARAM(5)*MALEAT(i,3);     %ca;
    param(6)=PARAM(6)*MALEAT(i,4);     %cs_nc;
    param(7)=PARAM(7)*MALEAT(i,5);     %cs_c;

    [mo,ro,Co,phio]=optimum(param,[],[],[0 NMAX 1],1,i);
    
    OUTPUT(i,1)=mo;
    OUTPUT(i,2)=ro;
    OUTPUT(i,3)=Co;

end


% =========================================================================
% Histogram Scenario 3 x Scenario 1 and Scenario 3 x Scenario 2
% =========================================================================

tfonte=7;
nfonte='Times';
x=20:1:43;
figure;
set(gcf,'Color',[1,1,1]);

subplot(2,2,1);
hist(OUTPUT(:,1),x);
h = findobj(gca,'Type','patch');
set(h,'FaceColor','w','EdgeColor','k');
xlim([20 44]);
set(gca,'XTick',20:2:44);
xlabel('m\circ','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
ylabel('frequency','FontSize',tfonte,'FontName','Times');
set(gca,'FontSize',tfonte,'FontName','Times')

drawnow;
set(gcf,'PaperPositionMode','auto');
print('-dpdf','-r120','figure8.pdf');
%close(gcf);

save figure8

